@@ -8,18 +8,18 @@
 */
 
 /* .Call calls */
-extern SEXP C_convhulln(SEXP, SEXP, SEXP, SEXP);
-extern SEXP C_delaunayn(SEXP, SEXP, SEXP);
-extern SEXP C_halfspacen(SEXP, SEXP, SEXP);
+extern SEXP C_convhulln(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP C_delaunayn(SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP C_halfspacen(SEXP, SEXP, SEXP, SEXP);
 extern SEXP C_inhulln(SEXP, SEXP);
 extern SEXP C_tsearch_orig(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP C_tsearchn(SEXP, SEXP);
 extern SEXP _geometry_C_tsearch(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
-    {"C_convhulln",           (DL_FUNC) &C_convhulln,         4},
-    {"C_delaunayn",           (DL_FUNC) &C_delaunayn,         3},
-    {"C_halfspacen",          (DL_FUNC) &C_halfspacen,        3},
+    {"C_convhulln",           (DL_FUNC) &C_convhulln,         5},
+    {"C_delaunayn",           (DL_FUNC) &C_delaunayn,         4},
+    {"C_halfspacen",          (DL_FUNC) &C_halfspacen,        4},
     {"C_inhulln",             (DL_FUNC) &C_inhulln,           2},
     {"C_tsearch_orig",        (DL_FUNC) &C_tsearch_orig,      6},
     {"C_tsearchn",            (DL_FUNC) &C_tsearchn,          2},
